@@ -22,6 +22,7 @@
 
 #include <QDialogButtonBox>
 #include <QPushButton>
+#include <QShortcut>
 
 SearchDialog::SearchDialog(CalendarView *calendarview)
     : QDialog(calendarview)
@@ -82,6 +83,11 @@ SearchDialog::SearchDialog(CalendarView *calendarview)
     //   connect(m_popupMenu, &KOEventPopupMenu::toggleTodoCompletedSignal, this,
     //           &SearchDialog::toggleTodoCompletedSignal);
 
+    const auto delKey = new QShortcut(QKeySequence(Qt::Key_Delete), this);
+    connect(delKey, &QShortcut::activated, this, &SearchDialog::slotDeleteSelection);
+    const auto retKey = new QShortcut(QKeySequence(Qt::Key_Return), this);
+    connect(retKey, &QShortcut::activated, this, &SearchDialog::slotEditSelection);
+
     readConfig();
 }
 
@@ -264,6 +270,22 @@ void SearchDialog::writeConfig()
     group.sync();
 }
 
+void SearchDialog::slotDeleteSelection()
+{
+    const auto selected = listView->selectedIncidences();
+    if (selected.count() > 0) {
+        Q_EMIT deleteIncidenceSignal(selected.at(0));
+    }
+}
+
+void SearchDialog::slotEditSelection()
+{
+    const auto selected = listView->selectedIncidences();
+    if (selected.count() > 0) {
+        Q_EMIT editIncidenceSignal(selected.at(0));
+    }
+}
+
 void SearchDialog::slotHelpRequested()
 {
     PimCommon::Util::invokeHelp(QStringLiteral("korganizer/search-view.html"));
